pub struct Cell {
pub symbol: char,
pub fg: Option<Color>,
pub bg: Option<Color>,
pub modifier: Modifier,
pub hyperlink_id: Option<u16>,
pub sequence_id: Option<u16>,
}Expand description
A single cell in the terminal buffer
Fields
symbol: charThe character in this cell
fg: Option<Color>Foreground color
bg: Option<Color>Background color
modifier: ModifierText modifiers (bold, italic, etc.)
hyperlink_id: Option<u16>Hyperlink ID (references Buffer’s hyperlink registry)
sequence_id: Option<u16>Escape sequence ID (references Buffer’s sequence registry) When set, the sequence is written instead of the symbol
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn is_continuation(&self) -> bool
pub fn is_continuation(&self) -> bool
Check if cell is a continuation of a wide character or escape sequence
Sourcepub fn continuation() -> Self
pub fn continuation() -> Self
Create a continuation cell (for wide characters or escape sequences)